==> aor-language-farsi-0.1.0.tgz: package/index.js <==
export default {
    aor: {
        action: {
            delete: 'حذف',
            show: 'نمایش',
            list: 'لیست',
            save: 'ذخیره',
            create: 'ایجاد',
            edit: 'ویرایش',
            cancel: 'کنسل',
            refresh: 'بروز‌رسانی',
            add_filter: 'اضافه‌کردن فیلتر',
            remove_filter: 'حذف این فیلتر',
        },
        boolean: {
            true: 'بله',
            false: 'خیر',
        },
        page: {
            list: '%{name} لیست',
            edit: '%{name} #%{id}',
            show: '%{name} #%{id}',
            create: 'ایجاد %{name}',
            delete: 'حذف %{name} #%{id}',
            dashboard: 'داشبورد',
        },
        input: {
            file: {
                upload_several: 'تعدادی فایل برای آپلود دراپ کنید، یا برای انتخاب آن‌ها کلیک کنید.',
                upload_single: 'فایلی را برای آپلود دراپ کنید، یا برای انتخاب آن کلیک کنید',
            },
            image: {
                upload_several: 'تعدادی عکس برای آپلود دراپ کنید، یا برای انتخاب آن‌ها کلیک کنید.',
                upload_single: 'عکسی را برای آپلود دراپ کنید، یا برای انتخاب آن کلیک کنید',
            },
        },
        message: {
            yes: 'بله',
            no: 'خیر',
            are_you_sure: 'آیا اطمینان دارید ؟',
            about: 'درباره',
        },
        navigation: {
            no_results: 'نتیجه‌ای پیدا نشد',
            page_out_of_boundaries: 'شماره صفحه %{page} خارج از محدوده است',
            page_out_from_end: 'نمی‌توان به بعد از صفحه آخر رفت',
            page_out_from_begin: 'نمی‌توان به قبل از صفحه اول رفت',
            page_range_info: '%{offsetBegin}-%{offsetEnd} از %{total}',
            next: 'بعدی',
            prev: 'قبلی',
        },
        auth: {
            username: 'نام‌کاربری',
            password: 'رمز عبور',
            sign_in: 'ورود',
            sign_in_error: 'شناسایی با شکست مواجه شد، دوباره تلاش کنید',
            logout: 'خروج',
        },
        notification: {
            updated: 'المان بروز‌رسانی شد',
            created: 'المان ایجاد شد',
            deleted: 'المان حذف شد',
            item_doesnt_exist: 'المان پیدا نشد',
            http_error: 'خطا در برقراری ارتباط با سرور',
        },
        validation: {
            required: 'اجباری',
            minLength: 'حداقل باید %{min} کارکتر باشد',
            maxLength: 'باید %{max} کارکتر یا کمتر باشد',
            minValue: 'حداقل باید %{min} باشد',
            maxValue: 'باید %{max} یا کمتر باشد',
            number: 'باید یک عدد باشد',
            email: 'باید یک آدرس ایمیل صحیح باشد',
        },
    },
};

==> aor-language-farsi-0.1.1.tgz: package/index.js <==
export default {
    aor: {
        action: {
            delete: 'حذف',
            show: 'نمایش',
            list: 'لیست',
            save: 'ذخیره',
            create: 'ایجاد',
            edit: 'ویرایش',
            cancel: 'کنسل',
            refresh: 'بروز‌رسانی',
            add_filter: 'اضافه‌کردن فیلتر',
            remove_filter: 'حذف این فیلتر',
        },
        boolean: {
            true: 'بله',
            false: 'خیر',
        },
        page: {
            list: 'لیست %{name}',
            edit: '%{name} #%{id}',
            show: '%{name} #%{id}',
            create: 'ایجاد %{name}',
            delete: 'حذف %{name} #%{id}',
            dashboard: 'داشبورد',
        },
        input: {
            file: {
                upload_several: 'تعدادی فایل برای آپلود دراپ کنید، یا برای انتخاب آن‌ها کلیک کنید.',
                upload_single: 'فایلی را برای آپلود دراپ کنید، یا برای انتخاب آن کلیک کنید',
            },
            image: {
                upload_several: 'تعدادی عکس برای آپلود دراپ کنید، یا برای انتخاب آن‌ها کلیک کنید.',
                upload_single: 'عکسی را برای آپلود دراپ کنید، یا برای انتخاب آن کلیک کنید',
            },
        },
        message: {
            yes: 'بله',
            no: 'خیر',
            are_you_sure: 'آیا اطمینان دارید ؟',
            about: 'درباره',
        },
        navigation: {
            no_results: 'نتیجه‌ای پیدا نشد',
            page_out_of_boundaries: 'شماره صفحه %{page} خارج از محدوده است',
            page_out_from_end: 'نمی‌توان به بعد از صفحه آخر رفت',
            page_out_from_begin: 'نمی‌توان به قبل از صفحه اول رفت',
            page_range_info: '{offsetBegin}%-{offsetEnd}% از {total}%',
            next: 'بعدی',
            prev: 'قبلی',
        },
        auth: {
            username: 'نام‌کاربری',
            password: 'رمز عبور',
            sign_in: 'ورود',
            sign_in_error: 'شناسایی با شکست مواجه شد، دوباره تلاش کنید',
            logout: 'خروج',
        },
        notification: {
            updated: 'المان بروز‌رسانی شد',
            created: 'المان ایجاد شد',
            deleted: 'المان حذف شد',
            item_doesnt_exist: 'المان پیدا نشد',
            http_error: 'خطا در برقراری ارتباط با سرور',
        },
        validation: {
            required: 'اجباری',
            minLength: 'حداقل باید %{min} کارکتر باشد',
            maxLength: 'باید %{max} کارکتر یا کمتر باشد',
            minValue: 'حداقل باید %{min} باشد',
            maxValue: 'باید %{max} یا کمتر باشد',
            number: 'باید یک عدد باشد',
            email: 'باید یک آدرس ایمیل صحیح باشد',
        },
    },
};
